# geohey

[![image](https://img.shields.io/pypi/v/geohey.svg)](https://pypi.python.org/pypi/geohey)
[![image](https://img.shields.io/conda/vn/conda-forge/geohey.svg)](https://anaconda.org/conda-forge/geohey)

**A Python package demo for geospatial analysis**

-   Free software: MIT License
-   Documentation: https://geohey.gishub.org

## Features

-   Visualizing raster and vector data
-   Analyzing raster and vector data
-   Visualizing raster data
-   Analyzing raster data
